API Reference
=============

.. currentmodule:: overpy

Overpass API
------------

.. autoclass:: Overpass
    :members:


Result
------

.. autoclass:: Result
    :members:


Elements
--------

.. autoclass:: Element
    :members:

.. autoclass:: Area
    :members:

.. autoclass:: Node
    :members:

.. autoclass:: Relation
    :members:

.. autoclass:: Way
    :members:


Relation Members
----------------

.. autoclass:: RelationMember
    :members:

.. autoclass:: RelationArea
    :members:

.. autoclass:: RelationNode
    :members:

.. autoclass:: RelationWay
    :members:


Exceptions
----------

.. automodule:: overpy.exception
    :members:


Helper
------

.. automodule:: overpy.helper
    :members:
